summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/worktoolbar.h
diff options
context:
space:
mode:
Diffstat (limited to 'umbrello/umbrello/worktoolbar.h')
-rw-r--r--umbrello/umbrello/worktoolbar.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/umbrello/umbrello/worktoolbar.h b/umbrello/umbrello/worktoolbar.h
index 1570b567..01b7c9a3 100644
--- a/umbrello/umbrello/worktoolbar.h
+++ b/umbrello/umbrello/worktoolbar.h
@@ -41,14 +41,15 @@ class TQMainWindow;
class WorkToolBar : public KToolBar {
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Creates a work tool bar.
*
* @param parentWindow The parent of the toolbar.
*/
- WorkToolBar(TQMainWindow *parentWindow, const char *name);
+ WorkToolBar(TQMainWindow *tqparentWindow, const char *name);
/**
* Standard deconstructor.
@@ -41,14 +41,15 @@ class TQMainWindow;
* Creates a work tool bar.
*
- * @param parentWindow The parent of the toolbar.
+ * @param tqparentWindow The tqparent of the toolbar.
*/